InputMessage

Enum InputMessage 

pub enum InputMessage {
    Premade {
        msgs: Vec<MixPacket>,
        lane: TransmissionLane,
    },
    Regular {
        recipient: Recipient,
        data: Vec<u8>,
        lane: TransmissionLane,
        max_retransmissions: Option<u32>,
    },
    Anonymous {
        recipient: Recipient,
        data: Vec<u8>,
        reply_surbs: u32,
        lane: TransmissionLane,
        max_retransmissions: Option<u32>,
    },
    Reply {
        recipient_tag: AnonymousSenderTag,
        data: Vec<u8>,
        lane: TransmissionLane,
        max_retransmissions: Option<u32>,
    },
    MessageWrapper {
        message: Box<InputMessage>,
        packet_type: PacketType,
    },
}

Variants



Premade

Fire an already prepared mix packets into the network. No guarantees are made about it. For example no retransmssion will be attempted if it gets dropped.



Regular

The simplest message variant where no additional information is attached. You’re simply sending your data to specified recipient without any tagging.

Ends up with NymMessage::Plain variant

Fields

recipient: Recipient
data: Vec<u8>
max_retransmissions: Option<u32>


Anonymous

Creates a message used for a duplex anonymous communication where the recipient will never learn of our true identity. This is achieved by carefully sending reply_surbs.

Note that if reply_surbs is set to zero then this variant requires the client having sent some reply_surbs in the past (and thus the recipient also knowing our sender tag).

Ends up with NymMessage::Repliable variant

Fields

recipient: Recipient
data: Vec<u8>
reply_surbs: u32
max_retransmissions: Option<u32>


Reply

Attempt to use our internally received and stored ReplySurb to send the message back to specified recipient whilst not knowing its full identity (or even gateway).

Ends up with NymMessage::Reply variant

Fields

recipient_tag: AnonymousSenderTag
data: Vec<u8>
max_retransmissions: Option<u32>


MessageWrapper

Fields

packet_type: PacketType

Implementations

Source

impl InputMessage

pub fn new_premade( msgs: Vec<MixPacket>, lane: TransmissionLane, packet_type: PacketType, ) -> InputMessage

pub fn new_wrapper( message: InputMessage, packet_type: PacketType, ) -> InputMessage

pub fn new_regular( recipient: Recipient, data: Vec<u8>, lane: TransmissionLane, packet_type: Option<PacketType>, ) -> InputMessage

pub fn new_anonymous( recipient: Recipient, data: Vec<u8>, reply_surbs: u32, lane: TransmissionLane, packet_type: Option<PacketType>, ) -> InputMessage

pub fn new_reply( recipient_tag: AnonymousSenderTag, data: Vec<u8>, lane: TransmissionLane, packet_type: Option<PacketType>, ) -> InputMessage

pub fn lane(&self) -> &TransmissionLane

pub fn set_max_retransmissions( &mut self, max_retransmissions: u32, ) -> &mut InputMessage

pub fn with_max_retransmissions(self, max_retransmissions: u32) -> InputMessage