pub struct ChainDetails {
pub bech32_account_prefix: String,
pub mix_denom: DenomDetailsOwned,
pub stake_denom: DenomDetailsOwned,
}Fields
bech32_account_prefix: Stringmix_denom: DenomDetailsOwnedstake_denom: DenomDetailsOwnedTrait Implementations
Sourceimpl Clone for ChainDetails
impl Clone for ChainDetails
Sourcefn clone(&self) -> ChainDetails
fn clone(&self) -> ChainDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChainDetails
impl Debug for ChainDetails
Sourceimpl<'de> Deserialize<'de> for ChainDetails
impl<'de> Deserialize<'de> for ChainDetails
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ChainDetails, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ChainDetails, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ChainDetails
impl Hash for ChainDetails
Sourceimpl JsonSchema for ChainDetails
impl JsonSchema for ChainDetails
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ChainDetails
impl PartialEq for ChainDetails
Sourceimpl Serialize for ChainDetails
impl Serialize for ChainDetails
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl ToSchema for ChainDetails
impl ToSchema for ChainDetails
impl Eq for ChainDetails
impl StructuralPartialEq for ChainDetails