pub struct DebugConfig {
pub traffic: Traffic,
pub cover_traffic: CoverTraffic,
pub gateway_connection: GatewayConnection,
pub acknowledgements: Acknowledgements,
pub topology: Topology,
pub reply_surbs: ReplySurbs,
pub stats_reporting: StatsReporting,
pub forget_me: ForgetMe,
pub remember_me: RememberMe,
}Fields
traffic: TrafficDefines all configuration options related to traffic streams.
cover_traffic: CoverTrafficDefines all configuration options related to cover traffic stream(s).
gateway_connection: GatewayConnectionDefines all configuration options related to the gateway connection.
acknowledgements: AcknowledgementsDefines all configuration options related to acknowledgements, such as delays or wait timeouts.
topology: TopologyDefines all configuration options related topology, such as refresh rates or timeouts.
reply_surbs: ReplySurbsDefines all configuration options related to reply SURBs.
stats_reporting: StatsReportingDefines all configuration options related to stats reporting.
forget_me: ForgetMeDefines all configuration options related to the forget me flag.
remember_me: RememberMeDefines all configuration options related to the remember me flag.
Implementations