pub struct MixnetClient { /* private fields */ }Expand description
Client connected to the Nym mixnet.
Implementations
Sourceimpl MixnetClient
impl MixnetClient
Sourcepub async fn connect_new() -> Result<Self>
pub async fn connect_new() -> Result<Self>
Create a new client and connect to the mixnet using ephemeral in-memory keys that are discarded at application close.
Examples
use nym_sdk::mixnet;
#[tokio::main]
async fn main() {
let mut client = mixnet::MixnetClient::connect_new().await;
}
Sourcepub fn nym_address(&self) -> &Recipient
pub fn nym_address(&self) -> &Recipient
Get the nym address for this client, if it is available. The nym address is composed of the client identity, the client encryption key, and the gateway identity.
Sourcepub fn cancellation_token(&self) -> CancellationToken
pub fn cancellation_token(&self) -> CancellationToken
Get a child token of the root, to monitor unexpected shutdown, without causing one
pub fn client_request_sender(&self) -> ClientRequestSender
Sourcepub fn identity_keypair(&self) -> Arc<KeyPair>
pub fn identity_keypair(&self) -> Arc<KeyPair>
Get the client’s identity keys.
Sourcepub fn sign(&self, data: &[u8]) -> Signature
pub fn sign(&self, data: &[u8]) -> Signature
Sign a message with the client’s private identity key.
Sourcepub fn sign_text(&self, text: &str) -> String
pub fn sign_text(&self, text: &str) -> String
Sign a message with the client’s private identity key and return it as a base58 encoded signature.
Sourcepub fn gateway_connection(&self) -> GatewayConnection
pub fn gateway_connection(&self) -> GatewayConnection
Get gateway connection information, like the file descriptor of the WebSocket
Sourcepub fn split_sender(&self) -> MixnetClientSender
pub fn split_sender(&self) -> MixnetClientSender
Get a shallow clone of MixnetClientSender. Useful if you want split the send and
receive logic in different locations.
Sourcepub fn connection_command_sender(&self) -> ConnectionCommandSender
pub fn connection_command_sender(&self) -> ConnectionCommandSender
Get a shallow clone of ConnectionCommandSender. This is useful if you want to e.g
explicitly close a transmission lane that is still sending data even though it should
cancel.
Get a shallow clone of LaneQueueLengths. This is useful to manually implement some form
of backpressure logic.
Sourcepub async fn manually_overwrite_topology(&self, new_topology: NymTopology)
pub async fn manually_overwrite_topology(&self, new_topology: NymTopology)
Change the network topology used by this client for constructing sphinx packets into the provided one.
Sourcepub async fn read_current_route_provider(
&self,
) -> Option<RwLockReadGuard<'_, NymRouteProvider>>
pub async fn read_current_route_provider( &self, ) -> Option<RwLockReadGuard<'_, NymRouteProvider>>
Gets the value of the currently used network topology.
Sourcepub fn restore_automatic_topology_refreshing(&self)
pub fn restore_automatic_topology_refreshing(&self)
Restore default topology refreshing behaviour of this client.
Sourcepub async fn wait_for_messages(&mut self) -> Option<Vec<ReconstructedMessage>>
pub async fn wait_for_messages(&mut self) -> Option<Vec<ReconstructedMessage>>
Wait for messages from the mixnet
Sourcepub async fn on_messages<F>(&mut self, fun: F)where
F: Fn(ReconstructedMessage),
pub async fn on_messages<F>(&mut self, fun: F)where
F: Fn(ReconstructedMessage),
Provide a callback to execute on incoming messages from the mixnet.
pub fn send_stats_event(&self, event: ClientStatsEvents)
Sourcepub fn stats_events_reporter(&self) -> ClientStatsSender
pub fn stats_events_reporter(&self) -> ClientStatsSender
Get a clone of stats_events_reporter for easier use
Sourcepub async fn disconnect(self)
pub async fn disconnect(self)
Disconnect from the mixnet. Currently, it is not supported to reconnect a disconnected client.
pub async fn send_forget_me(&self) -> Result<()>
pub async fn send_remember_me(&self) -> Result<()>